Command

Struct Command 

pub struct Command {
    pub id: u16,
    pub reply: bool,
    pub bytecode: Vec<u8>,
    /* private fields */
}
The packets that get sent to EV3. Can contain more than 1 OpCode

Example

let mut cmd = Command::new();
let mut byte = vec![];
// Add bytecode to byte
cmd.bytecode = byte;
println!("SENT: {:02X?}", cmd.gen_bytes());

Fields

id: u16

Command ID

reply: bool

Reply to direct command

bytecode: Vec<u8>

Bytes containing OpCodes and Parameter

Implementations

Source

impl Command

pub fn new() -> Self

pub fn gen_bytes(&self) -> Vec<u8>

Generate direct command bytecode

pub fn reserved_bytes(&self) -> usize

Get reserved bytes Can be use to initialize response buffer, with length of 5 + reserved_bytes().

pub fn mem_free(&mut self)

Free all allocated memory Causing any variables in bytecode to not work

Source

impl Command

pub fn allocate( &mut self, data: DataType, global: bool, ) -> Result<Vec<u8>, ValError>

Create variable bytecode and allocate space in Command Allocating global variables allow the values to be read in reply