Utility functions for ev3-dc
Terminology
- Layer: Index of daisy-chained EV3. i.e a single EV3 brick is a master which has layer of 0
Structs
- Chain
Byte - Chainable byte vector
Functions
- auto_
const - Encode local constant based on integer value
- device_
id - Return name of device id
- package_
bytes - Merge vector of small bytecode to vector of larger bytecode vector. Max length is set to 1000
- port_
read - Read port from u8 slice. 0-3 are inputs, 4-7 are outputs
- printer
- Convert vector of points from
run_lengthto direct commands Return vector of small line / dot bytecodes - read_
string - Read null-terminated string
- run_
length - Run-Length-Encoding on 1D 178x128 image array. Return (x1, y1, x2, y2) line bytecode.